@@ -31,6 +31,7 @@ const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
+const MapSource = imports.mapSource;
 const MapView = imports.mapView;
 const LayersPopover = imports.layersPopover;
 const ContextMenu = imports.contextMenu;
@@ -63,6 +64,8 @@ const MainWindow = new Lang.Class({
         this.mapView = new MapView.MapView();
         overlay.add(this.mapView);
 
+        overlay.add_overlay(new MapSource.AttributionLogo());
+
         this.mapView.gotoUserLocation(false);
 
         this._sidebar = new Sidebar.Sidebar(this.mapView);
